@@ -19,9 +19,7 @@
 pub mod client;
 pub mod http_message;
 pub mod server;
-pub mod logging_handler;
 pub mod handler;
-pub mod redirect_to_https_handler;
 pub mod headers;
 pub mod uri;
 pub mod query;
